@@ -34,6 +34,9 @@ static arglex_table_ty argtab[] =
 	{ "-Not_Description_Header", arglex_token_description_header_not, },
 	{ "-Entire_Source", arglex_token_entire_source, },
 	{ "-Not_Entire_Source", arglex_token_entire_source_not, },
+	{ "-PATch", arglex_token_patch, },
+	{ "-Not_PATch", arglex_token_patch_not, },
+	{ "-Partial_Source", arglex_token_entire_source_not, },
 	{ "-Receive", arglex_token_receive, },
 	{ "-Send", arglex_token_send, },
 	{ "-Trojan", arglex_token_trojan, },
