@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,10 +31,13 @@ enum
 	arglex_token_ascii_armor_not,
 	arglex_token_compress,
 	arglex_token_compress_not,
+	arglex_token_content_transfer_encoding,
 	arglex_token_description_header,
 	arglex_token_description_header_not,
 	arglex_token_entire_source,
 	arglex_token_entire_source_not,
+	arglex_token_patch,
+	arglex_token_patch_not,
 	arglex_token_receive,
 	arglex_token_send,
 	arglex_token_trojan,
@@ -42,6 +45,6 @@ enum
 	ARGLEX3_MAX
 };
 
-void arglex3_init _((int, char **));
+void arglex3_init(int, char **);
 
 #endif /* AEDIST_ARGLEX3_H */
