@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -22,14 +22,15 @@
 
 #include <ael/column_width.h>
 #include <arglex3.h>
-#include <cstate.h>
 #include <col.h>
+#include <cstate.h>
 #include <error.h> /* for assert */
 #include <help.h>
 #include <input/cpio.h>
 #include <list.h>
 #include <open.h>
 #include <os.h>
+#include <output.h>
 #include <str.h>
 #include <str_list.h>
 #include <sub.h>
@@ -39,20 +40,21 @@ void
 list_main(usage)
 	void		(*usage)_((void));
 {
-	char		*ifn;
+	string_ty	*ifn;
 	input_ty	*ifp;
 	input_ty	*cpio_p;
 	string_ty	*archive_name;
 	string_ty	*s;
 	cstate		change_set;
 	size_t		j;
-	char		*ofn;
-	int		head_col;
-	int		body_col;
+	string_ty	*ofn;
+	output_ty	*head_col;
+	output_ty	*body_col;
 	int		left;
-	int		usage_col;
-	int		action_col;
-	int		file_name_col;
+	output_ty	*usage_col;
+	output_ty	*action_col;
+	output_ty	*file_name_col;
+	col_ty		*colp;
 
 	ifn = 0;
 	ofn = 0;
@@ -67,17 +69,38 @@ list_main(usage)
 		case arglex_token_file:
 			if (ifn)
 				duplicate_option(usage);
-			if (arglex() != arglex_token_string)
+			switch (arglex())
+			{
+			default:
 				option_needs_file(arglex_token_file, usage);
-			ifn = arglex_value.alv_string;
+				/*NOTREACHED*/
+
+			case arglex_token_string:
+				ifn = str_from_c(arglex_value.alv_string);
+				break;
+
+			case arglex_token_stdio:
+				ifn = str_from_c("");
+				break;
+			}
 			break;
 
 		case arglex_token_output:
 			if (ofn)
 				duplicate_option(usage);
-			if (arglex() != arglex_token_string)
+			switch (arglex())
+			{
+			default:
 				option_needs_file(arglex_token_file, usage);
-			ofn = arglex_value.alv_string;
+
+			case arglex_token_string:
+				ofn = str_from_c(arglex_value.alv_string);
+				break;
+
+			case arglex_token_stdio:
+				ofn = str_from_c("");
+				break;
+			}
 			break;
 		}
 		arglex();
@@ -94,10 +117,10 @@ list_main(usage)
 	/*
 	 * Set the listing title from the change set subject line.
 	 */
-	col_open(ofn);
-	head_col = col_create(0, 0);
-	body_col = col_create(INDENT_WIDTH, 0);
-	col_title("Distribution Change Set", s->str_text);
+	colp = col_open(ofn);
+	head_col = col_create(colp, 0, 0, (const char *)0);
+	body_col = col_create(colp, INDENT_WIDTH, 0, (const char *)0);
+	col_title(colp, "Distribution Change Set", s->str_text);
 	str_free(s);
 
 	/*
@@ -108,38 +131,63 @@ list_main(usage)
 	archive_name = 0;
 	ifp = input_cpio_child(cpio_p, &archive_name);
 	if (!ifp)
-		input_format_error(cpio_p);
+		input_fatal_error(cpio_p, "file missing");
 	assert(archive_name);
 	s = str_from_c("etc/project-name");
 	if (!str_equal(archive_name, s))
-		input_format_error(ifp);
+		input_fatal_error(ifp, "wrong file");
 	str_free(s);
 	str_free(archive_name);
 
 	s = input_one_line(ifp);
 	if (!s || !s->str_length)
-		input_format_error(ifp);
+		input_fatal_error(ifp, "short file");
 	input_delete(ifp);
 	os_become_undo();
 
-	col_puts(head_col, "PROJECT");
-	col_eoln();
-	col_puts(body_col, s->str_text);
+	output_fputs(head_col, "PROJECT");
+	col_eoln(colp);
+	output_put_str(body_col, s);
 	str_free(s);
-	col_eoln();
 
 	/*
-	 * get the change details from the input
+         * read the change number from the archive, and use it to default
+         * the change number if not given, and if possible.
 	 */
 	os_become_orig();
 	archive_name = 0;
 	ifp = input_cpio_child(cpio_p, &archive_name);
 	if (!ifp)
-		input_format_error(cpio_p);
+		input_fatal_error(cpio_p, "file missing");
 	assert(archive_name);
+	s = str_from_c("etc/change-number");
+	if (str_equal(s, archive_name))
+	{
+	    str_free(s);
+	    s = input_one_line(ifp);
+	    input_delete(ifp);
+	    os_become_undo();
+	    str_free(archive_name);
+
+	    output_fputs(body_col, ", change ");
+	    output_put_str(body_col, s);
+	    str_free(s);
+
+	    os_become_orig();
+	    archive_name = 0;
+	    ifp = input_cpio_child(cpio_p, &archive_name);
+	    if (!ifp)
+		input_fatal_error(cpio_p, "file missing");
+	    assert(archive_name);
+	}
+	col_eoln(colp);
+
+	/*
+	 * get the change details from the input
+	 */
 	s = str_from_c("etc/change-set");
 	if (!str_equal(s, archive_name))
-		input_format_error(ifp);
+		input_fatal_error(ifp, "wrong file");
 	str_free(s);
 	change_set = parse_input(ifp, &cstate_type);
 	ifp = 0; /* parse_input input_delete()ed it for us */
@@ -159,7 +207,7 @@ list_main(usage)
 	||
 		!change_set->src->length
 	)
-		input_format_error(cpio_p);
+		input_fatal_error(cpio_p, "bad change set");
 	for (j = 0; j < change_set->src->length; ++j)
 	{
 		cstate_src	src_data;
@@ -175,66 +223,85 @@ list_main(usage)
 		||
 			!(src_data->mask & cstate_src_usage_mask)
 		)
-			input_format_error(cpio_p);
+			input_fatal_error(cpio_p, "bad file info");
 	}
 
-	col_need(1);
-	col_puts(head_col, "SUMMARY");
-	col_eoln();
-	col_puts(body_col, change_set->brief_description->str_text);
-	col_eoln();
+	col_need(colp, 3);
+	output_fputs(head_col, "SUMMARY");
+	col_eoln(colp);
+	output_put_str(body_col, change_set->brief_description);
+	col_eoln(colp);
 
-	col_need(5);
-	col_puts(head_col, "DESCRIPTION");
-	col_eoln();
-	col_puts(body_col, change_set->description->str_text);
-	col_eoln();
+	col_need(colp, 5);
+	output_fputs(head_col, "DESCRIPTION");
+	col_eoln(colp);
+	output_put_str(body_col, change_set->description);
+	col_eoln(colp);
 
 	/*
 	 * cause
 	 */
-	col_need(5);
-	col_puts(head_col, "CAUSE");
-	col_eoln();
-	col_printf
+	col_need(colp, 5);
+	output_fputs(head_col, "CAUSE");
+	col_eoln(colp);
+	output_fprintf
 	(
 		body_col,
 		"This change was caused by %s.",
 		change_cause_ename(change_set->cause)
 	);
-	col_eoln();
+	col_eoln(colp);
 
 	/*
 	 * files
 	 */
-	col_need(5);
-	col_puts(head_col, "FILES");
-	col_eoln();
+	col_need(colp, 5);
+	output_fputs(head_col, "FILES");
+	col_eoln(colp);
 
 	left = INDENT_WIDTH;
-	usage_col = col_create(left, left + USAGE_WIDTH);
+	usage_col =
+		col_create
+		(
+			colp,
+			left,
+			left + USAGE_WIDTH,
+			"Type\n-------"
+		);
 	left += USAGE_WIDTH + 1;
-	col_heading(usage_col, "Type\n-------");
 
-	action_col = col_create(left, left + ACTION_WIDTH);
+	action_col =
+		col_create
+		(
+			colp,
+			left,
+			left + ACTION_WIDTH,
+			"Action\n--------"
+		);
 	left += ACTION_WIDTH + 1;
-	col_heading(action_col, "Action\n--------");
 
-	file_name_col = col_create(left, 0);
-	col_heading(file_name_col, "File Name\n-----------");
+	file_name_col =
+		col_create
+		(
+			colp,
+			left,
+			0,
+			"File Name\n-----------"
+		);
+
 	for (j = 0; j < change_set->src->length; ++j)
 	{
 		cstate_src	src_data;
 
 		src_data = change_set->src->list[j];
 		assert(src_data->file_name);
-		col_puts(usage_col, file_usage_ename(src_data->usage));
-		col_puts(action_col, file_action_ename(src_data->action));
-		col_puts(file_name_col, src_data->file_name->str_text);
-		col_eoln();
+		output_fputs(usage_col, file_usage_ename(src_data->usage));
+		output_fputs(action_col, file_action_ename(src_data->action));
+		output_put_str(file_name_col, src_data->file_name);
+		col_eoln(colp);
 	}
 
 	input_delete(cpio_p);
-	col_close();
+	col_close(colp);
 	cstate_type.free(change_set);
 }
